
from vsg.rules import token_case_with_prefix_suffix

from vsg import token

lTokens = []
lTokens.append(token.package_body.end_package_simple_name)


class rule_507(token_case_with_prefix_suffix):
    '''
    This rule checks the package name has proper case on the end package declaration.

    |configuring_uppercase_and_lowercase_rules_link|

    **Violation**

    .. code-block:: vhdl

       end package body FIFO_PKG;

    **Fix**

    .. code-block:: vhdl

       end package fifo_pkg;
    '''

    def __init__(self):
        token_case_with_prefix_suffix.__init__(self, 'package_body', '507', lTokens)
        self.groups.append('case::name')




from vsg.rules import token_indent as Rule

from vsg import token

lTokens = []
lTokens.append(token.concurrent_selected_signal_assignment.with_keyword)
lTokens.append(token.selected_force_assignment.with_keyword)
lTokens.append(token.selected_variable_assignment.with_keyword)
lTokens.append(token.selected_waveform_assignment.with_keyword)


class rule_300(Rule):
    '''
    This rule checks the indent of the **with** keyword.

    **Violation**

    .. code-block:: vhdl

       wr_en <= '1';

           with mux_sel select addr <=
         "0000" when 0,
         "0001" when 1,
         "1111" when others;

    **Fix**

    .. code-block:: vhdl

       wr_en <= '1';

       with mux_sel select addr <=
         "0000" when 0,
         "0001" when 1,
         "1111" when others;
    '''

    def __init__(self):
        Rule.__init__(self, 'selected_assignment', '300', lTokens)




from vsg.rules import token_case

from vsg import token

lTokens = []
lTokens.append(token.case_statement.is_keyword)


class rule_015(token_case):
    '''
    This rule checks the **is** keyword has proper case.

    |configuring_uppercase_and_lowercase_rules_link|

    **Violation**

    .. code-block:: vhdl

         case address IS

         case address Is

         case address iS

    **Fix**

    .. code-block:: vhdl

         case address is

         case address is

         case address is
    '''

    def __init__(self):
        token_case.__init__(self, 'case', '015', lTokens)
        self.groups.append('case::keyword')




from vsg.rules import token_case

from vsg import token

lTokens = []
lTokens.append(token.block_statement.end_keyword)


class rule_504(token_case):
    '''
    This rule checks the **end** keyword has proper case.

    |configuring_uppercase_and_lowercase_rules_link|

    **Violation**

    .. code-block:: vhdl

       END block block_label;

    **Fix**

    .. code-block:: vhdl

       end block block_label;
    '''

    def __init__(self):
        token_case.__init__(self, 'block', '504', lTokens)
        self.groups.append('case::keyword')




from vsg.rules import blank_line_below_line_ending_with_token

from vsg.token import case_statement_alternative as token

lTokens = []
lTokens.append(token.assignment)


class rule_200(blank_line_below_line_ending_with_token):
    '''
    This rule checks for a blank line below the **=>** keyword.

    |configuring_blank_lines_link|

    **Violation**

    .. code-block:: vhdl

       when 0 =>
         a <= b;

    **Fix**

    .. code-block:: vhdl

       when 0 =>

         a <= b;
    '''

    def __init__(self):
        blank_line_below_line_ending_with_token.__init__(self, 'case', '200', lTokens)




from vsg.rules import token_case

from vsg import token

lTokens = []
lTokens.append(token.full_type_declaration.is_keyword)


class rule_013(token_case):
    '''
    This rule checks the **is** keyword in type definitions has proper case.

    |configuring_uppercase_and_lowercase_rules_link|

    **Violation**

    .. code-block:: vhdl

       type interface IS record
       type interface Is record
       type interface is record

    **Fix**

    .. code-block:: vhdl

       type interface is record
       type interface is record
       type interface is record
    '''

    def __init__(self):
        token_case.__init__(self, 'type', '013', lTokens)
        self.groups.append('case::keyword')




from vsg.rules import token_case as Rule

from vsg import token

lTokens = []
lTokens.append(token.loop_statement.end_loop_keyword)


class rule_502(Rule):
    '''
    This rule checks the **loop** keyword has proper case.

    |configuring_uppercase_and_lowercase_rules_link|

    **Violation**

    .. code-block:: vhdl

       while (condition) loop

       end LOOP;

    **Fix**

    .. code-block:: vhdl

       while (condition) loop

       end loop;
    '''

    def __init__(self):
        Rule.__init__(self, 'loop_statement', '502', lTokens)
        self.groups.append('case::keyword')




from vsg.rules import token_case_with_prefix_suffix

from vsg import token

lTokens = []
lTokens.append(token.context_declaration.identifier)


class rule_012(token_case_with_prefix_suffix):
    '''
    This rule checks the context identifier has proper case in the context declaration.

    |configuring_uppercase_and_lowercase_rules_link|

    **Violation**

    .. code-block:: vhdl

       context C1 is

    **Fix**

    .. code-block:: vhdl

       context c1 is
    '''

    def __init__(self):
        token_case_with_prefix_suffix.__init__(self, 'context', '012', lTokens)
        self.groups.append('case::name')




from vsg import token

from vsg.rules import move_token_left_to_next_non_whitespace_token as Rule

lTokens = []
lTokens.append(token.selected_expressions.when_keyword)
lTokens.append(token.selected_waveforms.when_keyword)


class rule_010(Rule):
    '''
    This rule checks the **when** keyword is on the same line as the expression or waveform.

    **Violation**

    .. code-block:: vhdl

       with mux_sel select addr <=
         "0000"
         when 0,
         "0001" when 1,
         "1111" when others;

    **Fix**

    .. code-block:: vhdl

       with mux_sel select addr <=
         "0000" when 0,
         "0001" when 1,
         "1111" when others;
    '''

    def __init__(self):
        Rule.__init__(self, 'selected_assignment', '010', lTokens)




from vsg.rules import previous_line

from vsg import token

lTokens = []
lTokens.append(token.procedure_specification.procedure_keyword)


class rule_200(previous_line):
    '''
    This rule checks for blank lines or comments above the **procedure** keyword.

    |configuring_previous_line_rules_link|

    **Violation**

    .. code-block:: vhdl

       architecture RTL of FIFO is
         procedure proc1 is


    **Fix**

    .. code-block:: vhdl

       architecture RTL of FIFO is

         procedure proc1 is
    '''

    def __init__(self):
        previous_line.__init__(self, 'procedure', '200', lTokens)
